@@ -1,7 +1,7 @@
 .onAttach <- function(libname, pkgname) {
-  tick <- as.numeric(substr(as.character(Sys.time()), 18, 19)) %% 2
+  tick <- stats::rbinom(n = 1, size = 1, prob = 0.4)
   if (tick == 1) {
-    packageStartupMessage("This is {comorbidity} version 1.0.0.")
+    packageStartupMessage("This is {comorbidity} version 1.0.2.")
     packageStartupMessage("A lot has changed since the last release on CRAN, please check-out breaking changes here:")
     packageStartupMessage("-> https://ellessenne.github.io/comorbidity/articles/C-changes.html")
   }
